# onemriganka


The package is currently under development and remains unstable at this stage. We recommend waiting for the stable release, which will be available with version 1.0.0 for public use.

## Installation
#### for developers

if you want to contribute or wnat to improve , you can install it from the pypi website and with the command below 

```bash
  pip install onemriganka
```
    
